@@ -3,7 +3,7 @@ package WebService::Toggl::API::Task;
 use WebService::Toggl::Role::Item as => 'JsonItem';
 
 use Moo;
-with 'WebService::Toggl::API';
+with 'WebService::Toggl::Role::API';
 use namespace::clean;
 
 with JsonItem(
