@@ -1,12 +1,12 @@
 package WebService::Toggl::API::Tasks;
 
 use Moo;
-with 'WebService::Toggl::API', 'WebService::Toggl::Role::Set';
+with 'WebService::Toggl::Role::API', 'WebService::Toggl::Role::Set';
 use namespace::clean;
 
 sub list_of { '::Task' }
 
-sub my_url { '/tasks' }
+sub api_path { 'tasks' }
 
 
 1;
